@@ -20,60 +20,43 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-           '-ggdb -O2 -pipe -Wall -Werror=format-security '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
-           '-ggdb -O2 -pipe -Wall -Werror=format-security '
-           '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
-                     '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                     '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                     '-I/usr/include/uuid/ '
-                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS': '',
+ 'CONFIGURE_CFLAGS_NODIST': '-ggdb -O2 -pipe -Wall -Werror=format-security '
+                            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                            '--param=ssp-buffer-size=4 '
+                            '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                            '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                            '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 '
+                            '-Wextra -Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9' "
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
                 "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python39' "
                 "'--htmldir=/usr/share/doc/python39/html' '-C' "
                 "'--enable-shared' '--enable-ipv6' '--with-libc=' "
                 "'--with-libm=' '--with-system-expat' '--with-system-ffi' "
                 "'--without-ensurepip' "
-                "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' "
-                "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
-                '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                '-I/usr/include/uuid/ '
-                '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                "-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1' "
+                "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/build/lcov-report',
+ 'COVERAGE_INFO': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include',
+             '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
  'DESTLIB': '/usr/lib/python3.9',
@@ -523,7 +506,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_CREATE': 0,
  'HAVE_UUID_ENC_BE': 0,
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
- 'HAVE_UUID_H': 1,
+ 'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
@@ -554,7 +537,6 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.9.dll.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
@@ -590,7 +572,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Modules/makesetup',
+ 'MAKESETUP': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -659,67 +641,66 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fwrapv -O3 -Wall -ggdb -O2 -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                             '-I/usr/include/uuid/ '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
-                             '-ggdb -O2 -pipe -Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                             '-I/usr/include/uuid/ '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
+                             '--param=ssp-buffer-size=4 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                             '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  '
-                             '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal '
+                             '-fvisibility=hidden -ggdb -O2 -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fstack-protector-strong '
+                             '--param=ssp-buffer-size=4 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                             '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+                             '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include '
+                             '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
-              '-ggdb -O2 -pipe -Wall -Werror=format-security '
-              '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-              '-I/usr/include/uuid/ '
-              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
-              '-ggdb -O2 -pipe -Wall -Werror=format-security '
-              '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-              '-I/usr/include/uuid/ '
-              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall',
+ 'PY_CFLAGS_NODIST': '-ggdb -O2 -pipe -Wall -Werror=format-security '
+                     '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                     '--param=ssp-buffer-size=4 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                     '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 '
+                     '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  '
-                     '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal',
+                     '-fvisibility=hidden -ggdb -O2 -pipe -Wall '
+                     '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                     '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                     '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+                     '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                   '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                   '-I/usr/include/uuid/ '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
+                   '--param=ssp-buffer-size=4 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                   '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
                    '-ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                   '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                   '-I/usr/include/uuid/ '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
-                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal '
+                   '--param=ssp-buffer-size=4 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                   '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+                   '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include '
+                   '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include',
+                '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
@@ -729,22 +710,21 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -Wall -ggdb -O2 -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
-                        '-ggdb -O2 -pipe -Wall -Werror=format-security '
-                        '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-                        '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                        '-I/usr/include/uuid/ '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
-                        '-std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                        '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  '
-                        '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal '
+                        '-fvisibility=hidden -ggdb -O2 -pipe -Wall '
+                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-fstack-protector-strong --param=ssp-buffer-size=4 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/build=/usr/src/debug/python39-3.9.9-3 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-3 '
+                        '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+                        '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include',
+                        '-I/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -782,7 +762,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39-x86_64-cygwin',
  'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -797,7 +777,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Tools/scripts/run_tests.py',
+               '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -805,11 +785,11 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 '
-                '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.9 '
+                '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VERSION': '3.9',
- 'VPATH': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9',
+ 'VPATH': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -821,9 +801,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/build',
- 'abs_srcdir': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9',
+ 'abs_builddir': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/build',
+ 'abs_srcdir': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9'}
+ 'srcdir': '/pub/devel/python/python39/python39-3.9.9-3.x86_64/src/Python-3.9.9'}
